pub enum AgentBuildPolicyError {
MissingSession,
MissingSessionMetadata,
MissingSessionBuildState,
MissingTurnStateHandle,
MissingToolVisibilityOwner,
LegacyInheritedToolFilterMetadata,
MissingInheritedToolVisibilityWitnesses,
InvalidFactoryBridgeToken,
ToolVisibilityRestore {
message: String,
},
ToolVisibilityPersist {
message: String,
},
}Expand description
Error returned when the canonical factory has not composed the policy state required before crossing into core agent construction.
Variants
MissingSession
MissingSessionMetadata
MissingSessionBuildState
MissingTurnStateHandle
MissingToolVisibilityOwner
LegacyInheritedToolFilterMetadata
MissingInheritedToolVisibilityWitnesses
InvalidFactoryBridgeToken
ToolVisibilityRestore
ToolVisibilityPersist