pub struct AuthMetadata {
pub account_id: Option<String>,
pub workspace_id: Option<String>,
pub organization_id: Option<String>,
pub user_id: Option<String>,
pub plan: Option<String>,
pub route_hints: AuthRouteHints,
pub provider_metadata: Option<ProviderAuthMetadata>,
}Expand description
Generic auth metadata attached to a resolved lease. Provider-specific
metadata goes under AuthMetadata::provider_metadata / AuthMetadata::route_hints.
Fields
account_id: Option<String>workspace_id: Option<String>organization_id: Option<String>user_id: Option<String>plan: Option<String>route_hints: AuthRouteHintsprovider_metadata: Option<ProviderAuthMetadata>Trait Implementations
Sourceimpl Clone for AuthMetadata
impl Clone for AuthMetadata
Sourcefn clone(&self) -> AuthMetadata
fn clone(&self) -> AuthMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AuthMetadata
impl Debug for AuthMetadata
Sourceimpl Default for AuthMetadata
impl Default for AuthMetadata
Sourcefn default() -> AuthMetadata
fn default() -> AuthMetadata
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for AuthMetadata
impl<'de> Deserialize<'de> for AuthMetadata
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AuthMetadata
impl JsonSchema for AuthMetadata
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AuthMetadata
impl PartialEq for AuthMetadata
Sourcefn eq(&self, other: &AuthMetadata) -> bool
fn eq(&self, other: &AuthMetadata) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AuthMetadata
impl Serialize for AuthMetadata
impl Eq for AuthMetadata
impl StructuralPartialEq for AuthMetadata