pub struct ProviderToolsConfig {
pub anthropic: AnthropicProviderToolsConfig,
pub openai: OpenAiProviderToolsConfig,
pub gemini: GeminiProviderToolsConfig,
}Expand description
Per-provider defaults for provider-native tools (web search, etc.).
These defaults are resolved at factory build time and injected as
non-persisted AgentConfig.provider_tool_defaults. The enabled flags
here control whether the factory injects tool config for models whose
ModelProfile.supports_web_search is true.
Fields
anthropic: AnthropicProviderToolsConfigopenai: OpenAiProviderToolsConfiggemini: GeminiProviderToolsConfigTrait Implementations
Sourceimpl Clone for ProviderToolsConfig
impl Clone for ProviderToolsConfig
Sourcefn clone(&self) -> ProviderToolsConfig
fn clone(&self) -> ProviderToolsConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProviderToolsConfig
impl Debug for ProviderToolsConfig
Sourceimpl Default for ProviderToolsConfig
impl Default for ProviderToolsConfig
Sourcefn default() -> ProviderToolsConfig
fn default() -> ProviderToolsConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ProviderToolsConfigwhere
ProviderToolsConfig: Default,
impl<'de> Deserialize<'de> for ProviderToolsConfigwhere
ProviderToolsConfig: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ProviderToolsConfig
impl PartialEq for ProviderToolsConfig
Sourceimpl Serialize for ProviderToolsConfig
impl Serialize for ProviderToolsConfig
impl StructuralPartialEq for ProviderToolsConfig