pub struct AuthProfile {
pub id: String,
pub provider: Provider,
pub auth_method: String,
pub source: CredentialSourceSpec,
pub constraints: AuthConstraints,
pub metadata_defaults: AuthMetadataDefaults,
}Expand description
Auth profile: how credentials are obtained, refreshed, constrained.
Fields
id: Stringprovider: Providerauth_method: Stringsource: CredentialSourceSpecconstraints: AuthConstraintsmetadata_defaults: AuthMetadataDefaultsTrait Implementations
Sourceimpl Clone for AuthProfile
impl Clone for AuthProfile
Sourcefn clone(&self) -> AuthProfile
fn clone(&self) -> AuthProfile
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AuthProfile
impl Debug for AuthProfile
Sourceimpl<'de> Deserialize<'de> for AuthProfile
impl<'de> Deserialize<'de> for AuthProfile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AuthProfile
impl JsonSchema for AuthProfile
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AuthProfile
impl PartialEq for AuthProfile
Sourcefn eq(&self, other: &AuthProfile) -> bool
fn eq(&self, other: &AuthProfile) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AuthProfile
impl Serialize for AuthProfile
impl Eq for AuthProfile
impl StructuralPartialEq for AuthProfile