pub struct AuthProfileConfig {
pub provider: String,
pub auth_method: String,
pub source: CredentialSourceSpec,
pub constraints: AuthConstraints,
pub metadata_defaults: AuthMetadataDefaults,
}Expand description
Serialized auth profile (pre-normalization).
Fields
provider: Stringauth_method: Stringsource: CredentialSourceSpecconstraints: AuthConstraintsmetadata_defaults: AuthMetadataDefaultsTrait Implementations
Sourceimpl Clone for AuthProfileConfig
impl Clone for AuthProfileConfig
Sourcefn clone(&self) -> AuthProfileConfig
fn clone(&self) -> AuthProfileConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AuthProfileConfig
impl Debug for AuthProfileConfig
Sourceimpl<'de> Deserialize<'de> for AuthProfileConfig
impl<'de> Deserialize<'de> for AuthProfileConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AuthProfileConfig
impl JsonSchema for AuthProfileConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AuthProfileConfig
impl PartialEq for AuthProfileConfig
Sourcefn eq(&self, other: &AuthProfileConfig) -> bool
fn eq(&self, other: &AuthProfileConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AuthProfileConfig
impl Serialize for AuthProfileConfig
impl Eq for AuthProfileConfig
impl StructuralPartialEq for AuthProfileConfig