pub struct BackendProfileConfig {
pub provider: String,
pub backend_kind: String,
pub base_url: Option<String>,
pub options: Value,
}Expand description
Serialized backend profile (pre-normalization).
Fields
provider: Stringbackend_kind: Stringbase_url: Option<String>options: ValueTrait Implementations
Sourceimpl Clone for BackendProfileConfig
impl Clone for BackendProfileConfig
Sourcefn clone(&self) -> BackendProfileConfig
fn clone(&self) -> BackendProfileConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BackendProfileConfig
impl Debug for BackendProfileConfig
Sourceimpl<'de> Deserialize<'de> for BackendProfileConfig
impl<'de> Deserialize<'de> for BackendProfileConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BackendProfileConfig
impl JsonSchema for BackendProfileConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BackendProfileConfig
impl PartialEq for BackendProfileConfig
Sourcefn eq(&self, other: &BackendProfileConfig) -> bool
fn eq(&self, other: &BackendProfileConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for BackendProfileConfig
impl Serialize for BackendProfileConfig
impl Eq for BackendProfileConfig
impl StructuralPartialEq for BackendProfileConfig