pub struct ProviderBindingConfig {
pub backend_profile: String,
pub auth_profile: String,
pub default_model: Option<String>,
pub policy: BindingPolicy,
}Expand description
Serialized binding (pre-normalization).
Fields
backend_profile: Stringauth_profile: Stringdefault_model: Option<String>policy: BindingPolicyTrait Implementations
Sourceimpl Clone for ProviderBindingConfig
impl Clone for ProviderBindingConfig
Sourcefn clone(&self) -> ProviderBindingConfig
fn clone(&self) -> ProviderBindingConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProviderBindingConfig
impl Debug for ProviderBindingConfig
Sourceimpl<'de> Deserialize<'de> for ProviderBindingConfig
impl<'de> Deserialize<'de> for ProviderBindingConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProviderBindingConfig
impl JsonSchema for ProviderBindingConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProviderBindingConfig
impl PartialEq for ProviderBindingConfig
Sourcefn eq(&self, other: &ProviderBindingConfig) -> bool
fn eq(&self, other: &ProviderBindingConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProviderBindingConfig
impl Serialize for ProviderBindingConfig
impl Eq for ProviderBindingConfig
impl StructuralPartialEq for ProviderBindingConfig