pub struct ResolvedConnectionTarget {
pub realm: RealmConnectionSet,
pub auth_binding: AuthBindingRef,
pub binding: ProviderBinding,
pub backend: BackendProfile,
pub auth_profile: AuthProfile,
}Expand description
Fully resolved connection target selected from config-owned identity policy. Surfaces should use this instead of inventing realm or binding defaults locally.
Fields
realm: RealmConnectionSetauth_binding: AuthBindingRefbinding: ProviderBindingbackend: BackendProfileauth_profile: AuthProfileTrait Implementations
Sourceimpl Clone for ResolvedConnectionTarget
impl Clone for ResolvedConnectionTarget
Sourcefn clone(&self) -> ResolvedConnectionTarget
fn clone(&self) -> ResolvedConnectionTarget
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResolvedConnectionTarget
impl Debug for ResolvedConnectionTarget
Sourceimpl PartialEq for ResolvedConnectionTarget
impl PartialEq for ResolvedConnectionTarget
Sourcefn eq(&self, other: &ResolvedConnectionTarget) -> bool
fn eq(&self, other: &ResolvedConnectionTarget) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ResolvedConnectionTarget
impl StructuralPartialEq for ResolvedConnectionTarget