ToolError

Enum ToolError 

pub enum ToolError {
    NotFound {
        name: String,
    },
    Unavailable {
        name: String,
        reason: String,
    },
    InvalidArguments {
        name: String,
        reason: String,
    },
    ExecutionFailed {
        message: String,
    },
    Timeout {
        name: String,
        timeout_ms: u64,
    },
    AccessDenied {
        name: String,
    },
    Other(String),
    CallbackPending {
        tool_name: String,
        args: Value,
    },
}
Error returned by tool dispatch operations.

Variants



NotFound

The requested tool was not found

Fields

name: String


Unavailable

The tool exists but is currently unavailable

Fields

name: String
reason: String


InvalidArguments

The tool arguments failed validation

Fields

name: String
reason: String


ExecutionFailed

The tool execution failed

Fields

message: String


Timeout

The tool execution timed out

Fields

name: String
timeout_ms: u64


AccessDenied

Tool access was denied by policy

Fields

name: String


Other(String)

A generic tool error with a message



CallbackPending

Tool call must be routed externally (callback pending)

This variant signals that a tool call cannot be handled internally and must be routed to an external handler. The payload contains serialized information about the pending tool call.

Fields

tool_name: String
args: Value

Implementations

Source

impl ToolError

pub fn error_code(&self) -> &'static str

pub fn to_error_payload(&self) -> Value

pub fn not_found(name: impl Into<String>) -> Self

pub fn unavailable(name: impl Into<String>, reason: impl Into<String>) -> Self

pub fn invalid_arguments( name: impl Into<String>, reason: impl Into<String>, ) -> Self

pub fn execution_failed(message: impl Into<String>) -> Self

pub fn timeout(name: impl Into<String>, timeout_ms: u64) -> Self

pub fn access_denied(name: impl Into<String>) -> Self

pub fn other(message: impl Into<String>) -> Self

pub fn callback_pending(tool_name: impl Into<String>, args: Value) -> Self

Create a callback pending error for external tool routing

pub fn is_callback_pending(&self) -> bool

Check if this is a callback pending error

pub fn as_callback_pending(&self) -> Option<(&str, &Value)>

Extract callback pending info if this is a CallbackPending error