pub enum ProviderTextDisposition {
NotEmitted,
UnsupportedByBackend,
EmittedButNotStored,
Captured {
text_artifact_ref: TextArtifactRef,
},
}Variants
NotEmitted
UnsupportedByBackend
EmittedButNotStored
Captured
Fields

text_artifact_ref: TextArtifactRefTrait Implementations
Sourceimpl Clone for ProviderTextDisposition
impl Clone for ProviderTextDisposition
Sourcefn clone(&self) -> ProviderTextDisposition
fn clone(&self) -> ProviderTextDisposition
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProviderTextDisposition
impl Debug for ProviderTextDisposition
Sourceimpl<'de> Deserialize<'de> for ProviderTextDisposition
impl<'de> Deserialize<'de> for ProviderTextDisposition
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProviderTextDisposition
Sourceimpl JsonSchema for ProviderTextDisposition
impl JsonSchema for ProviderTextDisposition
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProviderTextDisposition
impl PartialEq for ProviderTextDisposition
Sourcefn eq(&self, other: &ProviderTextDisposition) -> bool
fn eq(&self, other: &ProviderTextDisposition) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProviderTextDisposition
impl Serialize for ProviderTextDisposition
impl StructuralPartialEq for ProviderTextDisposition