pub struct InteractionId(pub Uuid);Expand description
Unique identifier for an interaction.
Tuple Fields
0: UuidTrait Implementations
Sourceimpl Clone for InteractionId
impl Clone for InteractionId
Sourcefn clone(&self) -> InteractionId
fn clone(&self) -> InteractionId
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InteractionId
impl Debug for InteractionId
Sourceimpl<'de> Deserialize<'de> for InteractionId
impl<'de> Deserialize<'de> for InteractionId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for InteractionId
impl Display for InteractionId
Sourceimpl Hash for InteractionId
impl Hash for InteractionId
Sourceimpl JsonSchema for InteractionId
impl JsonSchema for InteractionId
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for InteractionId
impl PartialEq for InteractionId
Sourceimpl Serialize for InteractionId
impl Serialize for InteractionId
impl Copy for InteractionId
impl Eq for InteractionId
impl StructuralPartialEq for InteractionId