pub struct SchemaWarning {
pub provider: Provider,
pub path: String,
pub message: String,
}Expand description
Warnings emitted during schema lowering.
Fields
provider: Providerpath: Stringmessage: StringTrait Implementations
Sourceimpl Clone for SchemaWarning
impl Clone for SchemaWarning
Sourcefn clone(&self) -> SchemaWarning
fn clone(&self) -> SchemaWarning
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SchemaWarning
impl Debug for SchemaWarning
Sourceimpl<'de> Deserialize<'de> for SchemaWarning
impl<'de> Deserialize<'de> for SchemaWarning
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SchemaWarning
impl JsonSchema for SchemaWarning
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SchemaWarning
impl PartialEq for SchemaWarning
Sourcefn eq(&self, other: &SchemaWarning) -> bool
fn eq(&self, other: &SchemaWarning) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SchemaWarning
impl Serialize for SchemaWarning
impl Eq for SchemaWarning
impl StructuralPartialEq for SchemaWarning