pub enum TranscriptEditRunningBehavior {
Reject,
}Expand description
Explicit behavior for transcript fork/edit requests when the source session has active work.
Variants
Reject
Reject the request while the source session is active.