pub struct SessionTranscriptRestoreRevisionRequest {
pub revision: String,
pub reason: TranscriptRewriteReason,
pub actor: Option<String>,
pub expected_parent_revision: Option<String>,
pub running_behavior: TranscriptEditRunningBehavior,
}Expand description
Request to restore the current transcript head to a retained revision body.
Fields
revision: Stringreason: TranscriptRewriteReasonactor: Option<String>expected_parent_revision: Option<String>running_behavior: TranscriptEditRunningBehaviorTrait Implementations
Sourceimpl Clone for SessionTranscriptRestoreRevisionRequest
impl Clone for SessionTranscriptRestoreRevisionRequest
Sourcefn clone(&self) -> SessionTranscriptRestoreRevisionRequest
fn clone(&self) -> SessionTranscriptRestoreRevisionRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for SessionTranscriptRestoreRevisionRequest
impl<'de> Deserialize<'de> for SessionTranscriptRestoreRevisionRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SessionTranscriptRestoreRevisionRequest
impl JsonSchema for SessionTranscriptRestoreRevisionRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SessionTranscriptRestoreRevisionRequest
impl RefUnwindSafe for SessionTranscriptRestoreRevisionRequest
impl Send for SessionTranscriptRestoreRevisionRequest
impl Sync for SessionTranscriptRestoreRevisionRequest
impl Unpin for SessionTranscriptRestoreRevisionRequest
impl UnsafeUnpin for SessionTranscriptRestoreRevisionRequest
impl UnwindSafe for SessionTranscriptRestoreRevisionRequest