pub struct SessionTranscriptRevisionQuery {
pub revision: String,
pub offset: usize,
pub limit: Option<usize>,
}Expand description
Query parameters for reading a retained transcript revision body.
Fields
revision: Stringoffset: usizeNumber of messages to skip from the start of the revision transcript.
limit: Option<usize>Maximum number of messages to return.