pub struct SessionTranscriptRewriteRequest {
pub selection: TranscriptRewriteSelection,
pub replacement: Vec<Message>,
pub reason: TranscriptRewriteReason,
pub actor: Option<String>,
pub expected_parent_revision: Option<String>,
pub running_behavior: TranscriptEditRunningBehavior,
}Expand description
Request to rewrite the current transcript head without changing SessionId.
Fields
selection: TranscriptRewriteSelectionreplacement: Vec<Message>reason: TranscriptRewriteReasonactor: Option<String>expected_parent_revision: Option<String>running_behavior: TranscriptEditRunningBehaviorTrait Implementations
Sourceimpl Clone for SessionTranscriptRewriteRequest
impl Clone for SessionTranscriptRewriteRequest
Sourcefn clone(&self) -> SessionTranscriptRewriteRequest
fn clone(&self) -> SessionTranscriptRewriteRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for SessionTranscriptRewriteRequest
impl<'de> Deserialize<'de> for SessionTranscriptRewriteRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SessionTranscriptRewriteRequest
impl JsonSchema for SessionTranscriptRewriteRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SessionTranscriptRewriteRequest
impl RefUnwindSafe for SessionTranscriptRewriteRequest
impl Send for SessionTranscriptRewriteRequest
impl Sync for SessionTranscriptRewriteRequest
impl Unpin for SessionTranscriptRewriteRequest
impl UnsafeUnpin for SessionTranscriptRewriteRequest
impl UnwindSafe for SessionTranscriptRewriteRequest