pub struct SessionTranscriptRewriteResult {
pub session_id: SessionId,
pub parent_revision: String,
pub revision: String,
pub message_count: usize,
pub commit: TranscriptRewriteCommit,
}Expand description
Result of committing a same-session transcript rewrite.
Fields
session_id: SessionIdparent_revision: Stringrevision: Stringmessage_count: usizecommit: TranscriptRewriteCommitTrait Implementations
Sourceimpl Clone for SessionTranscriptRewriteResult
impl Clone for SessionTranscriptRewriteResult
Sourcefn clone(&self) -> SessionTranscriptRewriteResult
fn clone(&self) -> SessionTranscriptRewriteResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for SessionTranscriptRewriteResult
impl<'de> Deserialize<'de> for SessionTranscriptRewriteResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SessionTranscriptRewriteResult
impl JsonSchema for SessionTranscriptRewriteResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SessionTranscriptRewriteResult
impl RefUnwindSafe for SessionTranscriptRewriteResult
impl Send for SessionTranscriptRewriteResult
impl Sync for SessionTranscriptRewriteResult
impl Unpin for SessionTranscriptRewriteResult
impl UnsafeUnpin for SessionTranscriptRewriteResult
impl UnwindSafe for SessionTranscriptRewriteResult