pub struct TranscriptRevisionBody {
pub revision: String,
pub parent_revision: Option<String>,
pub messages: Vec<Message>,
pub created_at: SystemTime,
}Expand description
Immutable transcript revision body retained by the session-local graph.
Fields
revision: Stringparent_revision: Option<String>messages: Vec<Message>created_at: SystemTimeTrait Implementations
Sourceimpl Clone for TranscriptRevisionBody
impl Clone for TranscriptRevisionBody
Sourcefn clone(&self) -> TranscriptRevisionBody
fn clone(&self) -> TranscriptRevisionBody
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TranscriptRevisionBody
impl Debug for TranscriptRevisionBody
Sourceimpl<'de> Deserialize<'de> for TranscriptRevisionBody
impl<'de> Deserialize<'de> for TranscriptRevisionBody
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TranscriptRevisionBody
impl JsonSchema for TranscriptRevisionBody
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TranscriptRevisionBody
impl RefUnwindSafe for TranscriptRevisionBody
impl Send for TranscriptRevisionBody
impl Sync for TranscriptRevisionBody
impl Unpin for TranscriptRevisionBody
impl UnsafeUnpin for TranscriptRevisionBody
impl UnwindSafe for TranscriptRevisionBody