pub struct TranscriptRewriteCommit {
pub parent_revision: String,
pub revision: String,
pub selection: TranscriptRewriteSelection,
pub original_span_digest: String,
pub replacement_digest: String,
pub messages_before: usize,
pub messages_after: usize,
pub reason: TranscriptRewriteReason,
pub actor: Option<String>,
pub committed_at: SystemTime,
}Expand description
Immutable rewrite commit that advances a session transcript head.
Fields
parent_revision: Stringrevision: Stringselection: TranscriptRewriteSelectionoriginal_span_digest: Stringreplacement_digest: Stringmessages_before: usizemessages_after: usizereason: TranscriptRewriteReasonactor: Option<String>committed_at: SystemTimeTrait Implementations
Sourceimpl Clone for TranscriptRewriteCommit
impl Clone for TranscriptRewriteCommit
Sourcefn clone(&self) -> TranscriptRewriteCommit
fn clone(&self) -> TranscriptRewriteCommit
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TranscriptRewriteCommit
impl Debug for TranscriptRewriteCommit
Sourceimpl<'de> Deserialize<'de> for TranscriptRewriteCommit
impl<'de> Deserialize<'de> for TranscriptRewriteCommit
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TranscriptRewriteCommit
impl JsonSchema for TranscriptRewriteCommit
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TranscriptRewriteCommit
impl PartialEq for TranscriptRewriteCommit
Sourcefn eq(&self, other: &TranscriptRewriteCommit) -> bool
fn eq(&self, other: &TranscriptRewriteCommit) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for TranscriptRewriteCommit
impl Serialize for TranscriptRewriteCommit
impl Eq for TranscriptRewriteCommit
impl StructuralPartialEq for TranscriptRewriteCommit